===============
pycolombianizer
===============


.. image:: https://img.shields.io/pypi/v/pycolombianizer.svg
        :target: https://pypi.python.org/pypi/pycolombianizer

.. image:: https://img.shields.io/travis/jcrodriguezu/pycolombianizer.svg
        :target: https://travis-ci.org/jcrodriguezu/pycolombianizer

.. image:: https://readthedocs.org/projects/pycolombianizer/badge/?version=latest
        :target: https://pycolombianizer.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Colombianize a string


* Free software: GNU General Public License v3
* Documentation: https://pycolombianizer.readthedocs.io.


Features
--------

* Return the Colombian representation of a string
* Use one of two Colombia slang to represent the string: Paisa or Costa

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
